clear
set mem 80m
#delimit;

/*Replication data for Thyne, Clayton (2006). ABC's, 123's, and the Golden Rule:
	The Pacifying Effect of Education on Civil War, 1980-1999.  International 
	Studies Quarterly. */

/**************TABLE 1**/
use "thyne-F&L-1.dta", clear;
/* T1, M1 */
logit onset warl gdpenl lpopl lmtnest ncontig Oil nwstate 
	instab anocl deml ethfrac relfrac ,nolog;

/* T1, M2 */
logit onset warl gdpenl lpopl lmtnest ncontig Oil nwstate 
	instab anocl deml ethfrac relfrac if year>=1980 ,nolog;

clear;
#delimit;

/*NOTE: You will need to download the "miest" command from Gary King's 
	website to run the commands below <http://gking.harvard.edu/stats.shtml> */

/*NOTE:  Sometimes the "miest" command gets fussy.  Try adding a "\" to the path name. 
	For instance, replace "E:Thy" with "E:\Thy". */

/* T1, M3 (replicating F&L with Amelia data) */
miest E:Thy logit onset warl gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl deml ethfrac relfrac;

/* T1, M4  (pri alone, without any edex) */
miest E:Thy logit onset warl pri gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl ,nolog;

/* T1, M5 (UNESCO edex as % of GNP alone, without pri) */
miest E:Thy logit onset warl edexgnp gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl ,nolog;

/* T1, M6 (using UNESCO edex as % of GNP) */
miest E:Thy logit onset warl edexgnp pri gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl  ,nolog;

/**************TABLE 2**/

/* T2, M1 */
miest E:Thy logit onset warl sec gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/* T2, M2 */
miest E:Thy logit onset warl secm gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/* T2, M3 */
miest E:Thy logit onset warl tert gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/* T2, M4 */
miest E:Thy logit onset warl literacy gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/***************FIGURE 1: enrollment levels overlaid */

clear;
#delimit;
use "Thy1.dta";

logit onset warl edexgnp pri gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl  ,nolog;

gen L1 = _b[_cons] + _b[pri]*pri +_b[edexgnp]*4.3011 + _b[warl]*0 + _b[gdpenl]*4.409 + _b[ lpopl]*9.1549 +
	_b[lmtnest]*2.0923 + _b[ncontig]*0 + _b[oil]*0 + _b[nwstate]*0 + _b[instab]*0 + _b[anocl]*0 ;

gen Phatpri = 1/(1 + exp(-L1));
label var Phatpri "Pr(onset--pri)";

drop L1;

logit onset warl sec gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  ,nolog;

gen L1 = _b[_cons] + _b[sec]*sec + _b[warl]*0 + _b[gdpenl]*4.409 + _b[ lpopl]*9.1549 
	+ _b[lmtnest]*2.0923 + _b[ncontig]*0 + _b[oil]*0 + _b[nwstate]*0 + _b[instab]*0 + _b[anocl]*0 ;

gen Phatsec = 1/(1 + exp(-L1)) ;
label var Phatsec "Pr(onset--sec)";

drop L1;

logit onset warl secm gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

gen L1 = _b[_cons] + _b[secm]*secm + _b[warl]*0 + _b[gdpenl]*4.409 + _b[ lpopl]*9.1549 
	+ _b[lmtnest]*2.0923 + _b[ncontig]*0 + _b[oil]*0 + _b[nwstate]*0 + _b[instab]*0 + _b[anocl]*0 ;

gen Phatsecm = 1/(1 + exp(-L1));
label var Phatsecm "Pr(onset--secm)";

drop L1;

twoway (mspline Phatpri pri, clcolor(black) clpat(solid) 
	clwidth(medthick)) (mspline Phatsec sec, clcolor(black) clpat(dash) 
	clwidth(medthick)) (mspline Phatsecm secm, clcolor(black) clpat(dash_dot) 
	clwidth(medthick)), ylabel(, noticks labels tlcolor(none) labcolor(none) 
	grid glcolor(white)) graphregion(ifcolor(none)) plotregion(ifcolor(none))
	yscale(range(0 (.01) .025)) ytitle(Probability of civil war onset) xtitle(Enrollment) 
	graphregion(fcolor(white) lcolor(white) lwidth(medthick) 
	ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white));

drop Phatpr Phatsec Phatsecm;

/**************FIGURE 2:  marginal effect PLOT of education expenditures 
when holding others constant */

logit onset warl edexgnp pri gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl  ,nolog;

gen L1 = _b[_cons] + _b[pri]*91.36 +_b[edexgnp]*edexgnp + _b[warl]*0 + _b[gdpenl]*4.409 + _b[ lpopl]*9.1549 
	+ _b[lmtnest]*2.0923 + _b[ncontig]*0 + _b[oil]*0 + _b[nwstate]*0 + _b[instab]*0 + _b[anocl]*0;

gen Phat1 = 1/(1 + exp(-L1));
label var Phat1 "Pr(onset)";
twoway (mspline Phat1 edexgnp, clwidth(medthick)), ylabel(, noticks labels tlcolor(none) 
	labcolor(none) grid glcolor(white)) graphregion(ifcolor(none)) plotregion(ifcolor(none))
	yscale(range(0 (.01) .025)) ytitle(Probability of civil war onset) 
	xtitle(Educational expenditures) graphregion(fcolor(white) lcolor(white) lwidth(medthick)
	ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white));

drop Phat1 L1;



/**************FIGURE 3:  marginal effect PLOT of literacy rates 
when holding others constant (T2 M7) */

logit onset warl literacy gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  ,nolog;

gen L1 = _b[_cons] + _b[literacy]*literacy + _b[warl]*0 + _b[gdpenl]*4.409 + _b[ lpopl]*9.1549 
	+ _b[lmtnest]*2.0923 + _b[ncontig]*0 + _b[oil]*0 + _b[nwstate]*0 + _b[instab]*0 + _b[anocl]*0 ;

gen Phat1 = 1/(1 + exp(-L1));
label var Phat1 "Pr(onset)";
twoway (mspline Phat1 literacy, clwidth(medthick)),  ylabel(, noticks labels
	tlcolor(none) labcolor(none) grid glcolor(white)) graphregion(ifcolor(none))
	plotregion(ifcolor(none))  yscale(range(0 (.01) .025)) 
	ytitle(Predicted probability of civil war onset) xtitle(Adult literacy rate) 
	graphregion(fcolor(white) lcolor(white) lwidth(medthick) 
	ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white));

drop Phat1 L1;

clear;

/**************TABLE 3**/
/*Note, the values in Table 3 are for the education variables only.  The controls are not shown. */

use "Thyne-Table3.dta", clear;

#delimit;

/****Model 1 */
/*Copied over from Table 1 and Table 2 (no replication) */

/****Model 2 (Only below average wealth countries): */
logit onset warl pri edexgnpl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if lowwealth==1, nolog;
logit onset warl sec lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if lowwealth==1,nolog;
logit onset warl secm lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if lowwealth==1,nolog;
logit onset warl tert lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if lowwealth==1,nolog;
logit onset warl literacy lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if lowwealth==1 ,nolog;
sum onset if lowwealth==1 & onset==1;

/****Model 3 (Only above average wealth countries): */
logit onset warl pri edexgnpl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if lowwealth==0, nolog;
logit onset warl sec lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if lowwealth==0,nolog;
logit onset warl secm lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if lowwealth==0,nolog;
logit onset warl tert lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if lowwealth==0,nolog;
logit onset warl literacy lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if lowwealth==0 ,nolog;
sum onset if lowwealth==0 & onset==1;

/****Model 4 (Only countries in the lowest quantile of wealth): */
logit onset warl edexgnpl pri lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth1==1, nolog;
logit onset warl sec lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth1==1,nolog;
logit onset warl secm lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth1==1,nolog;
logit onset warl tert lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth1==1,nolog;
logit onset warl literacy lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth1==1 ,nolog;
sum onset if wlth1==1 & onset==1;

/****Model 5 (Only countries in the second lowest quantile of wealth): */
logit onset warl edexgnpl pri lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth2==1, nolog;
logit onset warl sec lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth2==1,nolog;
logit onset warl secm lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth2==1,nolog;
logit onset warl tert lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth2==1,nolog;
logit onset warl literacy lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth2==1 ,nolog;
sum onset if wlth2==1 & onset==1;

/****Model 6 (Only countries in the middle quantile of wealth): */
logit onset warl edexgnpl pri lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth3==1, nolog;
logit onset warl sec lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth3==1,nolog;
logit onset warl secm lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth3==1,nolog;
logit onset warl tert lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth3==1,nolog;
logit onset warl literacy lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth3==1 ,nolog;
sum onset if wlth3==1 & onset==1;

/****Model 7 (Only countries in the 4th (second from top) quantile of wealth): */
logit onset warl edexgnpl pri lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth4==1, nolog;
logit onset warl sec lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth4==1,nolog;
logit onset warl secm lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth4==1,nolog;
logit onset warl tert lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac  if wlth4==1,nolog;
logit onset warl literacy lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac if wlth4==1 ,nolog;
sum onset if wlth4==1 & onset==1;

/****Model 8 (Only countries in the top quantile of wealth): */
/*NOTE: Dependent variable does not vary here (no civil wars in top quintile of wealth) */
sum onset if wlth5==1 & onset==1;

/**************TABLE 4**/

/*F&L w/ new Amelia imputations (not in the manuscript; here to show 
consistency w/ Fearon & Laitin's (2003) model) */
miest E:\Th logit onset warl  gdpenl lpopl lmtnest ncontig 
	oil nwstate instab   anocl ,nolog;

/* Model 1:  Immunization, measles (% of children ages 12-23 months) */
miest E:\Th logit onset warl  immMe gdpenl lpopl lmtnest ncontig 
	oil nwstate instab   anocl ,nolog;

/*Model 2:  Immunization, DPT (% of children ages 12-23 months) */
miest E:\Th logit onset warl  immDPT gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl  ,nolog;

/**************TABLE 5**/

/* protest, pri */
miest E:\Thy logit protdum pri gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl protpeace _Pspline1 _Pspline2 _Pspline3  ,nolog;

/*protest, edex */
miest E:\Thy logit protdum edexgnp gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl protpeace _Pspline1 _Pspline2 _Pspline3  ,nolog;

/*protest, sec */
miest E:\Thy logit protdum sec gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  protpeace _Pspline1 _Pspline2 _Pspline3  ,nolog;

/*protest, secm */
miest E:\Thy logit protdum secm gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  protpeace _Pspline1 _Pspline2 _Pspline3  ,nolog;

/*protest, tert */
miest E:\Thy logit protdum tert gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  protpeace _Pspline1 _Pspline2 _Pspline3  ,nolog;

/*protest, literacy */
miest E:\Thy logit protdum literacy gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  protpeace _Pspline1 _Pspline2 _Pspline3  ,nolog;

/*rebellion, pri */
miest E:\Thy logit rebdum pri gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl rebpeace _Rspline1 _Rspline2 _Rspline3  ,nolog;

/*rebellion, edex*/
miest E:\Thy logit rebdum edexgnp gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl rebpeace _Rspline1 _Rspline2 _Rspline3  ,nolog;

/*rebellion, sec*/
miest E:\Thy logit rebdum sec gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  rebpeace _Rspline1 _Rspline2 _Rspline3  ,nolog;

/*rebellion, secm*/
miest E:\Thy logit rebdum secm gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  rebpeace _Rspline1 _Rspline2 _Rspline3  ,nolog;

/*rebellion, tert*/
miest E:\Thy logit rebdum tert gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl  rebpeace _Rspline1 _Rspline2 _Rspline3  ,nolog;

/*rebellion, literacy*/
miest E:\Thy logit rebdum literacy gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl   rebpeace _Rspline1 _Rspline2 _Rspline3  ,nolog;

/****************APPENDIX:  Results mentioned in the text but not 
	included in the manuscript for Thyne, Clayton (2006). "ABC's, 123's and the Golden Rule: 
	The Pacifying Effect of Education on Civil Conflict, 1980-1999" */



/******Appendix Table 1:  Effect of Polity Interactions on the Probability of Civil War Onset 
	(mentioned on page XX) */

/* Appendix T1, M1 */
miest E:Thy logit onset warl pri pripolity polity gdpenl lpopl lmtnest ncontig 
	oil nwstate instab  ,nolog;

/* Appendix T1, M2 */
miest E:Thy logit onset warl edexgnp edexpolity polity gdpenl lpopl lmtnest ncontig 
	oil nwstate instab  ,nolog;

/* Appendix T1, M3 */
miest E:Thy logit onset warl sec secpolity polity gdpenl lpopl lmtnest 
	ncontig oil nwstate instab  ,nolog;

/* Appendix T1, M4 */
miest E:Thy logit onset warl secm secmpolity polity gdpenl lpopl lmtnest 
	ncontig oil nwstate instab  ,nolog;

/* Appendix T1, M5 */
miest E:\Thy logit onset warl tert tertpolity polity gdpenl lpopl lmtnest 
	ncontig oil nwstate instab  ,nolog;

/* Appendix T1, M6 */
miest E:Thy logit onset warl literacy litpolity polity gdpenl lpopl lmtnest 
	ncontig oil nwstate instab ,nolog;



/******Appendix Table 2:  Effect of Civil War History Interactions on the Probability of Civil War Onset 
	(mentioned on page XX) */

/* Appendix T2, M1 */
miest E:Thy logit onset pri pripw5 pw5 gdpenl lpopl lmtnest ncontig 
	oil nwstate instab  ,nolog;

/* Appendix T2, M2 */
miest E:Thy logit onset edexgnp edexpw5 pw5 gdpenl lpopl lmtnest ncontig 
	oil nwstate instab  ,nolog;

/* Appendix T2, M3 */
miest E:Thy logit onset sec secpw5 pw5 gdpenl lpopl lmtnest 
	ncontig oil nwstate instab  ,nolog;

/* Appendix T2, M4 */
miest E:Thy logit onset secm secmpw5 pw5 gdpenl lpopl lmtnest 
	ncontig oil nwstate instab  ,nolog;

/* Appendix T2, M5 */
miest E:\Thy logit onset tert tertpw5 pw5 gdpenl lpopl lmtnest 
	ncontig oil nwstate instab  ,nolog;

/* Appendix T2, M6 */
miest E:Thy logit onset literacy literacypw5 pw5 gdpenl lpopl lmtnest 
	ncontig oil nwstate instab ,nolog;



/****Appendix Table 3:  Logit analyses of determinants of civil war onset 
	using Barro and Lee education data (mentioned in footnote 12 on page XX) */

/*Appendix T3, M1 */
miest E:bar logit onset tyr25 warl gdpenl lpopl lmtnest ncontig Oil nwstate instab anocl deml ethfrac relfrac;

/*Appendix T3, M2 */
miest E:bar logit onset hyr25 warl gdpenl lpopl lmtnest ncontig Oil nwstate instab anocl deml ethfrac relfrac;

/*Appendix T3, M3 */
miest E:bar logit onset tyrm25 warl gdpenl lpopl lmtnest ncontig Oil nwstate instab anocl deml ethfrac relfrac;

/*Appendix T3, M4 */
miest E:bar logit onset hyrm25 warl gdpenl lpopl lmtnest ncontig Oil nwstate instab anocl deml ethfrac relfrac;



/****Appendix Table 4:  Replication of F&L 2003, 1945--1979 (mentioned on page XX) */

use "thyne-F&L-1.dta", clear;

logit onset warl gdpenl lpopl lmtnest ncontig Oil nwstate instab anocl deml ethfrac relfrac if year<=1979,nolog;

/****Appendix Table 5:  Smith-Blundel test of exogeneity, (mentioned on page XX) */

use "probexog.dta";

/*NOTE:  if you don't have this, use "findit probexog" */

/*null is exogeneity of the variable, the model for the endogenous variable comes 
	from Stastavage (2005, AJPS) */

probexog onset (pri = polity kidpop ruralpop gdppc gdpgrth) 
	warl gdpenl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac;

probexog onset (edexgnp = polity kidpop ruralpop gdppc gdpgrth) 
	warl gdpenl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac;

probexog onset (sec = polity kidpop ruralpop gdppc gdpgrth) 
	warl gdpenl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac;

probexog onset (secm = polity kidpop ruralpop gdppc gdpgrth) 
	warl gdpenl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac;

probexog onset (tert = polity kidpop ruralpop gdppc gdpgrth) 
	warl gdpenl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac;

probexog onset (literacy = polity kidpop ruralpop gdppc gdpgrth) 
	warl gdpenl lpopl lmtnest ncontig oil nwstate instab anocl deml ethfrac relfrac;



/******Appendix Table 6: The Effect of Education on Civil War Onset using the PRIO 
	Civil War Definition (mentioned on page XX) */

/* Appendix Table 6, M1 */
miest E:\Thy logit prioallonset prioallwarl pri gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl ,nolog;

/* Appendix Table 6, M2 */
miest E:\Thy logit prioallonset prioallwarl edexgnp gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl ,nolog;

/* Appendix Table 6 (M1 and M2 combined, not in appendix) */
miest E:\Thy logit prioallonset prioallwarl edexgnp pri gdpenl lpopl lmtnest ncontig 
	oil nwstate instab anocl  ,nolog;

/* Appendix Table 6, M3 */
miest E:\Thy logit prioallonset prioallwarl sec gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/* Appendix Table 6, M4 */
miest E:\Thy logit prioallonset prioallwarl secm gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/* Appendix Table 6, M5 */
miest E:\Thy logit prioallonset prioallwarl tert gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl ,nolog;

/* Appendix Table 6, M6 */
miest E:\Thy logit prioallonset prioallwarl literacy gdpenl lpopl lmtnest 
	ncontig oil nwstate instab anocl,nolog;


/*****Appendix Table 7:  summary stats table***********/

use "Thy.dta", clear;

set matsize 80;
misum E:\Thy _all;
